@@ -1,3 +1,4 @@
+import random
 class minesweeper:
 	"""
 	คลาส minesweeper คือ
@@ -51,6 +52,12 @@ class minesweeper:
 		"""
 		print(text)
 
+	def dice(self):
+		dice_list = ['⚀','⚁','⚂','⚃','⚄','⚅']
+		first = random.choice(dice_list)
+		second = random.choice(dice_list)
+		print('คุณทอดเต๋าได้: {} {}'.format(first,second))
+
 
 
 if __name__ == '__main__':
@@ -60,4 +67,4 @@ if __name__ == '__main__':
 	mine.show_youtube()
 	mine.about()
 	mine.show_art()
-
+	mine.dice()
